==> eleme-openapi-sdk-1.30.71-sources.jar: eleme/openapi/sdk/api/entity/brandOpenShop/CreateBasicShopInfoRequest.java <==
package eleme.openapi.sdk.api.entity.brandOpenShop;

import eleme.openapi.sdk.api.enumeration.*;
import eleme.openapi.sdk.api.entity.brandOpenShop.*;
import java.util.*;
import java.math.BigDecimal;
import com.fasterxml.jackson.annotation.JsonFormat;

public class CreateBasicShopInfoRequest{

    /**
     * 外部申请单id
     */
    private String outApplyId;
    public String getOutApplyId() {
        return outApplyId;
    }
    public void setOutApplyId(String outApplyId) {
        this.outApplyId = outApplyId;
    }
    
    /**
     * 饿了么申请单id
     */
    private Long eleApplyId;
    public Long getEleApplyId() {
        return eleApplyId;
    }
    public void setEleApplyId(Long eleApplyId) {
        this.eleApplyId = eleApplyId;
    }
    
    /**
     * 开店任务id
     */
    private String batchId;
    public String getBatchId() {
        return batchId;
    }
    public void setBatchId(String batchId) {
        this.batchId = batchId;
    }
    
    /**
     * 结算类型
     */
    private String settlementType;
    public String getSettlementType() {
        return settlementType;
    }
    public void setSettlementType(String settlementType) {
        this.settlementType = settlementType;
    }
    
    /**
     * 店铺类型
     */
    private Integer shopType;
    public Integer getShopType() {
        return shopType;
    }
    public void setShopType(Integer shopType) {
        this.shopType = shopType;
    }
    
    /**
     * 门店名称
     */
    private String shopName;
    public String getShopName() {
        return shopName;
    }
    public void setShopName(String shopName) {
        this.shopName = shopName;
    }
    
    /**
     * logo
     */
    private ImageDTO logo;
    public ImageDTO getLogo() {
        return logo;
    }
    public void setLogo(ImageDTO logo) {
        this.logo = logo;
    }
    
    /**
     * 主营品类
     */
    private CategoryInfoDTO mainCategory;
    public CategoryInfoDTO getMainCategory() {
        return mainCategory;
    }
    public void setMainCategory(CategoryInfoDTO mainCategory) {
        this.mainCategory = mainCategory;
    }
    
    /**
     * 副营品类
     */
    private CategoryInfoDTO subCategory;
    public CategoryInfoDTO getSubCategory() {
        return subCategory;
    }
    public void setSubCategory(CategoryInfoDTO subCategory) {
        this.subCategory = subCategory;
    }
    
    /**
     * 门店门脸图
     */
    private ImageDTO doorPic;
    public ImageDTO getDoorPic() {
        return doorPic;
    }
    public void setDoorPic(ImageDTO doorPic) {
        this.doorPic = doorPic;
    }
    
    /**
     * 店内环境图
     */
    private ImageDTO indoorPic;
    public ImageDTO getIndoorPic() {
        return indoorPic;
    }
    public void setIndoorPic(ImageDTO indoorPic) {
        this.indoorPic = indoorPic;
    }
    
    /**
     * 门店外卖电话
     */
    private String extPhone;
    public String getExtPhone() {
        return extPhone;
    }
    public void setExtPhone(String extPhone) {
        this.extPhone = extPhone;
    }
    
    /**
     * 门店联系人
     */
    private String masterName;
    public String getMasterName() {
        return masterName;
    }
    public void setMasterName(String masterName) {
        this.masterName = masterName;
    }
    
    /**
     * 门店联系人电话
     */
    private String masterMobile;
    public String getMasterMobile() {
        return masterMobile;
    }
    public void setMasterMobile(String masterMobile) {
        this.masterMobile = masterMobile;
    }
    
    /**
     * 门店行政区划信息
     */
    private AddressInfoDTO district;
    public AddressInfoDTO getDistrict() {
        return district;
    }
    public void setDistrict(AddressInfoDTO district) {
        this.district = district;
    }
    
    /**
     * 门店地址
     */
    private String address;
    public String getAddress() {
        return address;
    }
    public void setAddress(String address) {
        this.address = address;
    }
    
    /**
     * 门店纬度
     */
    private Double latitude;
    public Double getLatitude() {
        return latitude;
    }
    public void setLatitude(Double latitude) {
        this.latitude = latitude;
    }
    
    /**
     * 门店经度
     */
    private Double longitude;
    public Double getLongitude() {
        return longitude;
    }
    public void setLongitude(Double longitude) {
        this.longitude = longitude;
    }
    
    /**
     * 主体资质类型
     */
    private Integer businessLicenseType;
    public Integer getBusinessLicenseType() {
        return businessLicenseType;
    }
    public void setBusinessLicenseType(Integer businessLicenseType) {
        this.businessLicenseType = businessLicenseType;
    }
    
    /**
     * 主体资质照片
     */
    private ImageDTO businessLicensePic;
    public ImageDTO getBusinessLicensePic() {
        return businessLicensePic;
    }
    public void setBusinessLicensePic(ImageDTO businessLicensePic) {
        this.businessLicensePic = businessLicensePic;
    }
    
    /**
     * 主体资质注册号
     */
    private String businessLicenseNo;
    public String getBusinessLicenseNo() {
        return businessLicenseNo;
    }
    public void setBusinessLicenseNo(String businessLicenseNo) {
        this.businessLicenseNo = businessLicenseNo;
    }
    
    /**
     * 主体资质的单位名称
     */
    private String businessLicenseName;
    public String getBusinessLicenseName() {
        return businessLicenseName;
    }
    public void setBusinessLicenseName(String businessLicenseName) {
        this.businessLicenseName = businessLicenseName;
    }
    
    /**
     * 主体资质的经营场所
     */
    private String businessLicenseAddress;
    public String getBusinessLicenseAddress() {
        return businessLicenseAddress;
    }
    public void setBusinessLicenseAddress(String businessLicenseAddress) {
        this.businessLicenseAddress = businessLicenseAddress;
    }
    
    /**
     * 主体资质的有效期
     */
    private String businessLicenseExpireData;
    public String getBusinessLicenseExpireData() {
        return businessLicenseExpireData;
    }
    public void setBusinessLicenseExpireData(String businessLicenseExpireData) {
        this.businessLicenseExpireData = businessLicenseExpireData;
    }
    
    /**
     * 主体资质的法定代表人
     */
    private String businessLicenseLegalPerson;
    public String getBusinessLicenseLegalPerson() {
        return businessLicenseLegalPerson;
    }
    public void setBusinessLicenseLegalPerson(String businessLicenseLegalPerson) {
        this.businessLicenseLegalPerson = businessLicenseLegalPerson;
    }
    
    /**
     * 行业资质类型
     */
    private Integer businessPermitType;
    public Integer getBusinessPermitType() {
        return businessPermitType;
    }
    public void setBusinessPermitType(Integer businessPermitType) {
        this.businessPermitType = businessPermitType;
    }
    
    /**
     * 行业资质法定代表人
     */
    private String businessPermitLegalPerson;
    public String getBusinessPermitLegalPerson() {
        return businessPermitLegalPerson;
    }
    public void setBusinessPermitLegalPerson(String businessPermitLegalPerson) {
        this.businessPermitLegalPerson = businessPermitLegalPerson;
    }
    
    /**
     * 行业资质单位名称
     */
    private String businessPermitName;
    public String getBusinessPermitName() {
        return businessPermitName;
    }
    public void setBusinessPermitName(String businessPermitName) {
        this.businessPermitName = businessPermitName;
    }
    
    /**
     * 行业资质许可证编号
     */
    private String businessPermitNo;
    public String getBusinessPermitNo() {
        return businessPermitNo;
    }
    public void setBusinessPermitNo(String businessPermitNo) {
        this.businessPermitNo = businessPermitNo;
    }
    
    /**
     * 行业资质经营场所
     */
    private String businessPermitAddress;
    public String getBusinessPermitAddress() {
        return businessPermitAddress;
    }
    public void setBusinessPermitAddress(String businessPermitAddress) {
        this.businessPermitAddress = businessPermitAddress;
    }
    
    /**
     * 行业资质的有效期
     */
    private String businessPermitExpireData;
    public String getBusinessPermitExpireData() {
        return businessPermitExpireData;
    }
    public void setBusinessPermitExpireData(String businessPermitExpireData) {
        this.businessPermitExpireData = businessPermitExpireData;
    }
    
    /**
     * 行业资质照片
     */
    private ImageDTO businessPermitPic;
    public ImageDTO getBusinessPermitPic() {
        return businessPermitPic;
    }
    public void setBusinessPermitPic(ImageDTO businessPermitPic) {
        this.businessPermitPic = businessPermitPic;
    }
    
    /**
     * 行业资质主体业态
     */
    private String businessPermitScope;
    public String getBusinessPermitScope() {
        return businessPermitScope;
    }
    public void setBusinessPermitScope(String businessPermitScope) {
        this.businessPermitScope = businessPermitScope;
    }
    
    /**
     * 行业资质营业项目
     */
    private String businessPermitMainBusiness;
    public String getBusinessPermitMainBusiness() {
        return businessPermitMainBusiness;
    }
    public void setBusinessPermitMainBusiness(String businessPermitMainBusiness) {
        this.businessPermitMainBusiness = businessPermitMainBusiness;
    }
    
    /**
     * 法定代表人资质的证件类型
     */
    private Integer legalPersonLicenseType;
    public Integer getLegalPersonLicenseType() {
        return legalPersonLicenseType;
    }
    public void setLegalPersonLicenseType(Integer legalPersonLicenseType) {
        this.legalPersonLicenseType = legalPersonLicenseType;
    }
    
    /**
     * 法定代表人真实姓名
     */
    private String legalPersonName;
    public String getLegalPersonName() {
        return legalPersonName;
    }
    public void setLegalPersonName(String legalPersonName) {
        this.legalPersonName = legalPersonName;
    }
    
    /**
     * 法定代表人证件号码
     */
    private String legalPersonLicenseNo;
    public String getLegalPersonLicenseNo() {
        return legalPersonLicenseNo;
    }
    public void setLegalPersonLicenseNo(String legalPersonLicenseNo) {
        this.legalPersonLicenseNo = legalPersonLicenseNo;
    }
    
    /**
     * 法定代表人证件人像照或正面照
     */
    private ImageDTO legalPersonLicenseFrontPic;
    public ImageDTO getLegalPersonLicenseFrontPic() {
        return legalPersonLicenseFrontPic;
    }
    public void setLegalPersonLicenseFrontPic(ImageDTO legalPersonLicenseFrontPic) {
        this.legalPersonLicenseFrontPic = legalPersonLicenseFrontPic;
    }
    
    /**
     * 法定代表人证件国徽面
     */
    private ImageDTO legalPersonLicenseBackPic;
    public ImageDTO getLegalPersonLicenseBackPic() {
        return legalPersonLicenseBackPic;
    }
    public void setLegalPersonLicenseBackPic(ImageDTO legalPersonLicenseBackPic) {
        this.legalPersonLicenseBackPic = legalPersonLicenseBackPic;
    }
    
    /**
     * 法定代表人手持证件照
     */
    private ImageDTO legalPersonHoldOnPic;
    public ImageDTO getLegalPersonHoldOnPic() {
        return legalPersonHoldOnPic;
    }
    public void setLegalPersonHoldOnPic(ImageDTO legalPersonHoldOnPic) {
        this.legalPersonHoldOnPic = legalPersonHoldOnPic;
    }
    
    /**
     * 法定代表人证件有效期
     */
    private String legalPersonExpireData;
    public String getLegalPersonExpireData() {
        return legalPersonExpireData;
    }
    public void setLegalPersonExpireData(String legalPersonExpireData) {
        this.legalPersonExpireData = legalPersonExpireData;
    }
    
    /**
     * 更多资质
     */
    private List<SpecialPermitInfoDTO> specialPermit;
    public List<SpecialPermitInfoDTO> getSpecialPermit() {
        return specialPermit;
    }
    public void setSpecialPermit(List<SpecialPermitInfoDTO> specialPermit) {
        this.specialPermit = specialPermit;
    }
    
    /**
     * 开店方式
     */
    private Integer createShopType;
    public Integer getCreateShopType() {
        return createShopType;
    }
    public void setCreateShopType(Integer createShopType) {
        this.createShopType = createShopType;
    }
    
    /**
     * 营业环境图
     */
    private ImageDTO businessEnvironmentPic;
    public ImageDTO getBusinessEnvironmentPic() {
        return businessEnvironmentPic;
    }
    public void setBusinessEnvironmentPic(ImageDTO businessEnvironmentPic) {
        this.businessEnvironmentPic = businessEnvironmentPic;
    }
    
}

==> eleme-openapi-sdk-1.31.37-sources.jar: eleme/openapi/sdk/api/entity/brandOpenShop/CreateBasicShopInfoRequest.java <==
package eleme.openapi.sdk.api.entity.brandOpenShop;

import eleme.openapi.sdk.api.enumeration.brandOpenShop.*;
import eleme.openapi.sdk.api.entity.brandOpenShop.*;
import java.util.*;
import java.math.BigDecimal;
import com.fasterxml.jackson.annotation.JsonFormat;

public class CreateBasicShopInfoRequest{

    /**
     * 外部申请单id
     */
    private String outApplyId;
    public String getOutApplyId() {
        return outApplyId;
    }
    public void setOutApplyId(String outApplyId) {
        this.outApplyId = outApplyId;
    }
    
    /**
     * 饿了么申请单id
     */
    private Long eleApplyId;
    public Long getEleApplyId() {
        return eleApplyId;
    }
    public void setEleApplyId(Long eleApplyId) {
        this.eleApplyId = eleApplyId;
    }
    
    /**
     * 开店任务id
     */
    private String batchId;
    public String getBatchId() {
        return batchId;
    }
    public void setBatchId(String batchId) {
        this.batchId = batchId;
    }
    
    /**
     * 结算类型
     */
    private String settlementType;
    public String getSettlementType() {
        return settlementType;
    }
    public void setSettlementType(String settlementType) {
        this.settlementType = settlementType;
    }
    
    /**
     * 店铺类型
     */
    private Integer shopType;
    public Integer getShopType() {
        return shopType;
    }
    public void setShopType(Integer shopType) {
        this.shopType = shopType;
    }
    
    /**
     * 门店名称
     */
    private String shopName;
    public String getShopName() {
        return shopName;
    }
    public void setShopName(String shopName) {
        this.shopName = shopName;
    }
    
    /**
     * logo
     */
    private ImageDTO logo;
    public ImageDTO getLogo() {
        return logo;
    }
    public void setLogo(ImageDTO logo) {
        this.logo = logo;
    }
    
    /**
     * 主营品类
     */
    private CategoryInfoDTO mainCategory;
    public CategoryInfoDTO getMainCategory() {
        return mainCategory;
    }
    public void setMainCategory(CategoryInfoDTO mainCategory) {
        this.mainCategory = mainCategory;
    }
    
    /**
     * 副营品类
     */
    private CategoryInfoDTO subCategory;
    public CategoryInfoDTO getSubCategory() {
        return subCategory;
    }
    public void setSubCategory(CategoryInfoDTO subCategory) {
        this.subCategory = subCategory;
    }
    
    /**
     * 门店门脸图
     */
    private ImageDTO doorPic;
    public ImageDTO getDoorPic() {
        return doorPic;
    }
    public void setDoorPic(ImageDTO doorPic) {
        this.doorPic = doorPic;
    }
    
    /**
     * 店内环境图
     */
    private ImageDTO indoorPic;
    public ImageDTO getIndoorPic() {
        return indoorPic;
    }
    public void setIndoorPic(ImageDTO indoorPic) {
        this.indoorPic = indoorPic;
    }
    
    /**
     * 门店外卖电话
     */
    private String extPhone;
    public String getExtPhone() {
        return extPhone;
    }
    public void setExtPhone(String extPhone) {
        this.extPhone = extPhone;
    }
    
    /**
     * 门店联系人
     */
    private String masterName;
    public String getMasterName() {
        return masterName;
    }
    public void setMasterName(String masterName) {
        this.masterName = masterName;
    }
    
    /**
     * 门店联系人电话
     */
    private String masterMobile;
    public String getMasterMobile() {
        return masterMobile;
    }
    public void setMasterMobile(String masterMobile) {
        this.masterMobile = masterMobile;
    }
    
    /**
     * 门店行政区划信息
     */
    private AddressInfoDTO district;
    public AddressInfoDTO getDistrict() {
        return district;
    }
    public void setDistrict(AddressInfoDTO district) {
        this.district = district;
    }
    
    /**
     * 门店地址
     */
    private String address;
    public String getAddress() {
        return address;
    }
    public void setAddress(String address) {
        this.address = address;
    }
    
    /**
     * 门店纬度(必须使用高德坐标体系)
     */
    private Double latitude;
    public Double getLatitude() {
        return latitude;
    }
    public void setLatitude(Double latitude) {
        this.latitude = latitude;
    }
    
    /**
     * 门店经度(必须使用高德坐标体系)
     */
    private Double longitude;
    public Double getLongitude() {
        return longitude;
    }
    public void setLongitude(Double longitude) {
        this.longitude = longitude;
    }
    
    /**
     * 主体资质类型
     */
    private Integer businessLicenseType;
    public Integer getBusinessLicenseType() {
        return businessLicenseType;
    }
    public void setBusinessLicenseType(Integer businessLicenseType) {
        this.businessLicenseType = businessLicenseType;
    }
    
    /**
     * 主体资质照片
     */
    private ImageDTO businessLicensePic;
    public ImageDTO getBusinessLicensePic() {
        return businessLicensePic;
    }
    public void setBusinessLicensePic(ImageDTO businessLicensePic) {
        this.businessLicensePic = businessLicensePic;
    }
    
    /**
     * 主体资质注册号
     */
    private String businessLicenseNo;
    public String getBusinessLicenseNo() {
        return businessLicenseNo;
    }
    public void setBusinessLicenseNo(String businessLicenseNo) {
        this.businessLicenseNo = businessLicenseNo;
    }
    
    /**
     * 主体资质的单位名称
     */
    private String businessLicenseName;
    public String getBusinessLicenseName() {
        return businessLicenseName;
    }
    public void setBusinessLicenseName(String businessLicenseName) {
        this.businessLicenseName = businessLicenseName;
    }
    
    /**
     * 主体资质的经营场所
     */
    private String businessLicenseAddress;
    public String getBusinessLicenseAddress() {
        return businessLicenseAddress;
    }
    public void setBusinessLicenseAddress(String businessLicenseAddress) {
        this.businessLicenseAddress = businessLicenseAddress;
    }
    
    /**
     * 主体资质的有效期
     */
    private String businessLicenseExpireData;
    public String getBusinessLicenseExpireData() {
        return businessLicenseExpireData;
    }
    public void setBusinessLicenseExpireData(String businessLicenseExpireData) {
        this.businessLicenseExpireData = businessLicenseExpireData;
    }
    
    /**
     * 主体资质的法定代表人
     */
    private String businessLicenseLegalPerson;
    public String getBusinessLicenseLegalPerson() {
        return businessLicenseLegalPerson;
    }
    public void setBusinessLicenseLegalPerson(String businessLicenseLegalPerson) {
        this.businessLicenseLegalPerson = businessLicenseLegalPerson;
    }
    
    /**
     * 行业资质类型
     */
    private Integer businessPermitType;
    public Integer getBusinessPermitType() {
        return businessPermitType;
    }
    public void setBusinessPermitType(Integer businessPermitType) {
        this.businessPermitType = businessPermitType;
    }
    
    /**
     * 行业资质法定代表人
     */
    private String businessPermitLegalPerson;
    public String getBusinessPermitLegalPerson() {
        return businessPermitLegalPerson;
    }
    public void setBusinessPermitLegalPerson(String businessPermitLegalPerson) {
        this.businessPermitLegalPerson = businessPermitLegalPerson;
    }
    
    /**
     * 行业资质单位名称
     */
    private String businessPermitName;
    public String getBusinessPermitName() {
        return businessPermitName;
    }
    public void setBusinessPermitName(String businessPermitName) {
        this.businessPermitName = businessPermitName;
    }
    
    /**
     * 行业资质许可证编号
     */
    private String businessPermitNo;
    public String getBusinessPermitNo() {
        return businessPermitNo;
    }
    public void setBusinessPermitNo(String businessPermitNo) {
        this.businessPermitNo = businessPermitNo;
    }
    
    /**
     * 行业资质经营场所
     */
    private String businessPermitAddress;
    public String getBusinessPermitAddress() {
        return businessPermitAddress;
    }
    public void setBusinessPermitAddress(String businessPermitAddress) {
        this.businessPermitAddress = businessPermitAddress;
    }
    
    /**
     * 行业资质的有效期
     */
    private String businessPermitExpireData;
    public String getBusinessPermitExpireData() {
        return businessPermitExpireData;
    }
    public void setBusinessPermitExpireData(String businessPermitExpireData) {
        this.businessPermitExpireData = businessPermitExpireData;
    }
    
    /**
     * 行业资质照片
     */
    private ImageDTO businessPermitPic;
    public ImageDTO getBusinessPermitPic() {
        return businessPermitPic;
    }
    public void setBusinessPermitPic(ImageDTO businessPermitPic) {
        this.businessPermitPic = businessPermitPic;
    }
    
    /**
     * 行业资质主体业态
     */
    private String businessPermitMainBusiness;
    public String getBusinessPermitMainBusiness() {
        return businessPermitMainBusiness;
    }
    public void setBusinessPermitMainBusiness(String businessPermitMainBusiness) {
        this.businessPermitMainBusiness = businessPermitMainBusiness;
    }
    
    /**
     * 行业资质营业项目
     */
    private String businessPermitScope;
    public String getBusinessPermitScope() {
        return businessPermitScope;
    }
    public void setBusinessPermitScope(String businessPermitScope) {
        this.businessPermitScope = businessPermitScope;
    }
    
    /**
     * 法定代表人资质的证件类型
     */
    private Integer legalPersonLicenseType;
    public Integer getLegalPersonLicenseType() {
        return legalPersonLicenseType;
    }
    public void setLegalPersonLicenseType(Integer legalPersonLicenseType) {
        this.legalPersonLicenseType = legalPersonLicenseType;
    }
    
    /**
     * 法定代表人真实姓名
     */
    private String legalPersonName;
    public String getLegalPersonName() {
        return legalPersonName;
    }
    public void setLegalPersonName(String legalPersonName) {
        this.legalPersonName = legalPersonName;
    }
    
    /**
     * 法定代表人证件号码
     */
    private String legalPersonLicenseNo;
    public String getLegalPersonLicenseNo() {
        return legalPersonLicenseNo;
    }
    public void setLegalPersonLicenseNo(String legalPersonLicenseNo) {
        this.legalPersonLicenseNo = legalPersonLicenseNo;
    }
    
    /**
     * 法定代表人证件人像照或正面照
     */
    private ImageDTO legalPersonLicenseFrontPic;
    public ImageDTO getLegalPersonLicenseFrontPic() {
        return legalPersonLicenseFrontPic;
    }
    public void setLegalPersonLicenseFrontPic(ImageDTO legalPersonLicenseFrontPic) {
        this.legalPersonLicenseFrontPic = legalPersonLicenseFrontPic;
    }
    
    /**
     * 法定代表人证件国徽面
     */
    private ImageDTO legalPersonLicenseBackPic;
    public ImageDTO getLegalPersonLicenseBackPic() {
        return legalPersonLicenseBackPic;
    }
    public void setLegalPersonLicenseBackPic(ImageDTO legalPersonLicenseBackPic) {
        this.legalPersonLicenseBackPic = legalPersonLicenseBackPic;
    }
    
    /**
     * 法定代表人手持证件照
     */
    private ImageDTO legalPersonHoldOnPic;
    public ImageDTO getLegalPersonHoldOnPic() {
        return legalPersonHoldOnPic;
    }
    public void setLegalPersonHoldOnPic(ImageDTO legalPersonHoldOnPic) {
        this.legalPersonHoldOnPic = legalPersonHoldOnPic;
    }
    
    /**
     * 法定代表人证件有效期
     */
    private String legalPersonExpireData;
    public String getLegalPersonExpireData() {
        return legalPersonExpireData;
    }
    public void setLegalPersonExpireData(String legalPersonExpireData) {
        this.legalPersonExpireData = legalPersonExpireData;
    }
    
    /**
     * 更多资质
     */
    private List<SpecialPermitInfoDTO> specialPermit;
    public List<SpecialPermitInfoDTO> getSpecialPermit() {
        return specialPermit;
    }
    public void setSpecialPermit(List<SpecialPermitInfoDTO> specialPermit) {
        this.specialPermit = specialPermit;
    }
    
    /**
     * 开店方式
     */
    private Integer createShopType;
    public Integer getCreateShopType() {
        return createShopType;
    }
    public void setCreateShopType(Integer createShopType) {
        this.createShopType = createShopType;
    }
    
    /**
     * 营业环境图
     */
    private ImageDTO businessEnvironmentPic;
    public ImageDTO getBusinessEnvironmentPic() {
        return businessEnvironmentPic;
    }
    public void setBusinessEnvironmentPic(ImageDTO businessEnvironmentPic) {
        this.businessEnvironmentPic = businessEnvironmentPic;
    }
    
}
